from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PdefinedCls:
	"""Pdefined commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdefined", core, parent)

	def set(self, color: enums.Color, item=repcap.Item.Default) -> None:
		"""SCPI: HCOPy:CMAP<it>:PDEFined \n
		Snippet: driver.hardCopy.cmap.pdefined.set(color = enums.Color.BLACk, item = repcap.Item.Default) \n
		This command selects a predefined color for various screen elements in print jobs. \n
			:param color: BLACk | BLUE | BROWn | GREen | CYAN | RED | MAGenta | YELLow | WHITe | DGRay | LGRay | LBLue | LGReen | LCYan | LRED | LMAGenta
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
		"""
		param = Conversions.enum_scalar_to_str(color, enums.Color)
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		self._core.io.write(f'HCOPy:CMAP{item_cmd_val}:PDEFined {param}')

	# noinspection PyTypeChecker
	def get(self, item=repcap.Item.Default) -> enums.Color:
		"""SCPI: HCOPy:CMAP<it>:PDEFined \n
		Snippet: value: enums.Color = driver.hardCopy.cmap.pdefined.get(item = repcap.Item.Default) \n
		This command selects a predefined color for various screen elements in print jobs. \n
			:param item: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Cmap')
			:return: color: BLACk | BLUE | BROWn | GREen | CYAN | RED | MAGenta | YELLow | WHITe | DGRay | LGRay | LBLue | LGReen | LCYan | LRED | LMAGenta"""
		item_cmd_val = self._cmd_group.get_repcap_cmd_value(item, repcap.Item)
		response = self._core.io.query_str(f'HCOPy:CMAP{item_cmd_val}:PDEFined?')
		return Conversions.str_to_scalar_enum(response, enums.Color)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DirectionCls:
	"""Direction commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("direction", core, parent)

	# noinspection PyTypeChecker
	def get(self) -> enums.XyDirection:
		"""SCPI: LAYout:DIRection \n
		Snippet: value: enums.XyDirection = driver.layout.direction.get() \n
		No command help available \n
			:return: direction: No help available"""
		response = self._core.io.query_str_with_opc(f'LAYout:DIRection?')
		return Conversions.str_to_scalar_enum(response, enums.XyDirection)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LanResetCls:
	"""LanReset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("lanReset", core, parent)

	def set(self) -> None:
		"""SCPI: SYSTem:LXI:LANReset \n
		Snippet: driver.system.lxi.lanReset.set() \n
		This command resets the LAN configuration, as well as the 'LAN' password and instrument description. \n
		"""
		self._core.io.write(f'SYSTem:LXI:LANReset')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SYSTem:LXI:LANReset \n
		Snippet: driver.system.lxi.lanReset.set_with_opc() \n
		This command resets the LAN configuration, as well as the 'LAN' password and instrument description. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SYSTem:LXI:LANReset', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TraceCls:
	"""Trace commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trace", core, parent)

	def set(self, trace_number: float) -> None:
		"""SCPI: [SENSe]:POWer:TRACe \n
		Snippet: driver.sense.power.trace.set(trace_number = 1.0) \n
		No command help available \n
			:param trace_number: No help available
		"""
		param = Conversions.decimal_value_to_str(trace_number)
		self._core.io.write(f'SENSe:POWer:TRACe {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:POWer:TRACe \n
		Snippet: value: float = driver.sense.power.trace.get() \n
		No command help available \n
			:return: trace_number: No help available"""
		response = self._core.io.query_str(f'SENSe:POWer:TRACe?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, data_type: enums.IqDataFormat, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:IQ:FORMat \n
		Snippet: driver.massMemory.store.iq.formatPy.set(data_type = enums.IqDataFormat.FloatComplex=FLOat32,COMPlex, store = repcap.Store.Default) \n
		No command help available \n
			:param data_type: No help available
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = Conversions.enum_scalar_to_str(data_type, enums.IqDataFormat)
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write_with_opc(f'MMEMory:STORe{store_cmd_val}:IQ:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, store=repcap.Store.Default) -> enums.IqDataFormat:
		"""SCPI: MMEMory:STORe<n>:IQ:FORMat \n
		Snippet: value: enums.IqDataFormat = driver.massMemory.store.iq.formatPy.get(store = repcap.Store.Default) \n
		No command help available \n
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
			:return: data_type: No help available"""
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		response = self._core.io.query_str_with_opc(f'MMEMory:STORe{store_cmd_val}:IQ:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.IqDataFormat)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, group: enums.DdemGroup) -> None:
		"""SCPI: [SENSe]:DDEMod:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.formatPy.set(group = enums.DdemGroup.APSK) \n
		This command selects the digital demodulation mode. \n
			:param group: MSK | PSK | QAM | QPSK | FSK | ASK | APSK | UQAM QPSK Quad Phase Shift Key PSK Phase Shift Key MSK Minimum Shift Key QAM Quadrature Amplitude Modulation FSK Frequency Shift Key ASK Amplitude Shift Keying APSK Amplitude Phase Shift Keying UQAM User-defined modulation (loaded from file, see [SENSe:]DDEMod:USER:NAME)
		"""
		param = Conversions.enum_scalar_to_str(group, enums.DdemGroup)
		self._core.io.write(f'SENSe:DDEMod:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DdemGroup:
		"""SCPI: [SENSe]:DDEMod:FORMat \n
		Snippet: value: enums.DdemGroup = driver.applications.k70Vsa.sense.ddemod.formatPy.get() \n
		This command selects the digital demodulation mode. \n
			:return: group: MSK | PSK | QAM | QPSK | FSK | ASK | APSK | UQAM QPSK Quad Phase Shift Key PSK Phase Shift Key MSK Minimum Shift Key QAM Quadrature Amplitude Modulation FSK Frequency Shift Key ASK Amplitude Shift Keying APSK Amplitude Phase Shift Keying UQAM User-defined modulation (loaded from file, see [SENSe:]DDEMod:USER:NAME)"""
		response = self._core.io.query_str(f'SENSe:DDEMod:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.DdemGroup)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:ADEMod:AF:STARt \n
		Snippet: driver.sense.ademod.af.start.set(frequency = 1.0) \n
		This command sets the start frequency for AF spectrum result display. \n
			:param frequency: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:ADEMod:AF:STARt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:AF:STARt \n
		Snippet: value: float = driver.sense.ademod.af.start.get() \n
		This command sets the start frequency for AF spectrum result display. \n
			:return: frequency: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:ADEMod:AF:STARt?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrangeCls:
	"""Srange commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("srange", core, parent)

	def set(self, search_range: enums.SearchRange) -> None:
		"""SCPI: [SENSe]:CREFerence:SRANge \n
		Snippet: driver.applications.k50Spurious.sense.creference.srange.set(search_range = enums.SearchRange.GMAXimum) \n
		Determines the search area for the automatic carrier measurement function. \n
			:param search_range: GMAXimum | RMAXimum GMAXimum Global maximum: The maximum peak in the entire measurement span is determined. RMAXimum Range maximum: The maximum peak is searched only in the specified range.
		"""
		param = Conversions.enum_scalar_to_str(search_range, enums.SearchRange)
		self._core.io.write(f'SENSe:CREFerence:SRANge {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SearchRange:
		"""SCPI: [SENSe]:CREFerence:SRANge \n
		Snippet: value: enums.SearchRange = driver.applications.k50Spurious.sense.creference.srange.get() \n
		Determines the search area for the automatic carrier measurement function. \n
			:return: search_range: GMAXimum | RMAXimum GMAXimum Global maximum: The maximum peak in the entire measurement span is determined. RMAXimum Range maximum: The maximum peak is searched only in the specified range."""
		response = self._core.io.query_str(f'SENSe:CREFerence:SRANge?')
		return Conversions.str_to_scalar_enum(response, enums.SearchRange)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	@property
	def relative(self):
		"""relative commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Relative import RelativeCls
			self._relative = RelativeCls(self._core, self._cmd_group)
		return self._relative

	def set(self, stimulus: float, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:X \n
		Snippet: driver.applications.k50Spurious.calculate.deltaMarker.x.set(stimulus = 1.0, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command moves a delta marker to a particular coordinate on the x-axis. If necessary, the command activates the delta
		marker and positions a reference marker to the peak power. \n
			:param stimulus: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.decimal_value_to_str(stimulus)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:X {param}')

	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> float:
		"""SCPI: CALCulate<n>:DELTamarker<m>:X \n
		Snippet: value: float = driver.applications.k50Spurious.calculate.deltaMarker.x.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command moves a delta marker to a particular coordinate on the x-axis. If necessary, the command activates the delta
		marker and positions a reference marker to the peak power. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: stimulus: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:X?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'XCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = XCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CorrectionCls:
	"""Correction commands group definition. 50 total commands, 6 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("correction", core, parent)

	@property
	def temperature(self):
		"""temperature commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_temperature'):
			from .Temperature import TemperatureCls
			self._temperature = TemperatureCls(self._core, self._cmd_group)
		return self._temperature

	@property
	def loss(self):
		"""loss commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_loss'):
			from .Loss import LossCls
			self._loss = LossCls(self._core, self._cmd_group)
		return self._loss

	@property
	def irejection(self):
		"""irejection commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_irejection'):
			from .Irejection import IrejectionCls
			self._irejection = IrejectionCls(self._core, self._cmd_group)
		return self._irejection

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def enr(self):
		"""enr commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_enr'):
			from .Enr import EnrCls
			self._enr = EnrCls(self._core, self._cmd_group)
		return self._enr

	@property
	def save(self):
		"""save commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_save'):
			from .Save import SaveCls
			self._save = SaveCls(self._core, self._cmd_group)
		return self._save

	def recall(self, recall_file_path: str) -> None:
		"""SCPI: [SENSe]:CORRection:RECall \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.recall(recall_file_path = '1') \n
		Sets the calibration results recall filepath and recalls the calibration results. \n
			:param recall_file_path: No help available
		"""
		param = Conversions.value_to_quoted_str(recall_file_path)
		self._core.io.write(f'SENSe:CORRection:RECall {param}')

	def clone(self) -> 'CorrectionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CorrectionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WindowCls:
	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("window", core, parent)

	def get(self, window_name: str) -> int:
		"""SCPI: LAYout:IDENtify[:WINDow] \n
		Snippet: value: int = driver.applications.k60Transient.layout.identify.window.get(window_name = '1') \n
		This command queries the index of a particular display window in the active channel. Note: to query the name of a
		particular window, use the LAYout:WINDow<n>:IDENtify? query. \n
			:param window_name: String containing the name of a window.
			:return: window_index: Index number of the window."""
		param = Conversions.value_to_quoted_str(window_name)
		response = self._core.io.query_str_with_opc(f'LAYout:IDENtify:WINDow? {param}')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WidthCls:
	"""Width commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("width", core, parent)

	def set(self, pulse_width: float) -> None:
		"""SCPI: SOURce:GENerator:PULSe:WIDTh \n
		Snippet: driver.source.generator.pulse.width.set(pulse_width = 1.0) \n
		This command defines the length of the pulse that is generated.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Optional pulsed phase noise measurements.
			- Turn on signal source (method RsFswp.Applications.K30_NoiseFigure.Source.Generator.State.set) .
			- Turn on pulse modulation (method RsFswp.Source.Generator.Modulation.set) . \n
			:param pulse_width: numeric value Unit: s
		"""
		param = Conversions.decimal_value_to_str(pulse_width)
		self._core.io.write(f'SOURce:GENerator:PULSe:WIDTh {param}')

	def get(self) -> float:
		"""SCPI: SOURce:GENerator:PULSe:WIDTh \n
		Snippet: value: float = driver.source.generator.pulse.width.get() \n
		This command defines the length of the pulse that is generated.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Optional pulsed phase noise measurements.
			- Turn on signal source (method RsFswp.Applications.K30_NoiseFigure.Source.Generator.State.set) .
			- Turn on pulse modulation (method RsFswp.Source.Generator.Modulation.set) . \n
			:return: pulse_width: numeric value Unit: s"""
		response = self._core.io.query_str(f'SOURce:GENerator:PULSe:WIDTh?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LinkCls:
	"""Link commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("link", core, parent)

	def set(self, type_py: enums.GeneratorLink, generator=repcap.Generator.Default) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:LINK \n
		Snippet: driver.system.communicate.rdevice.generator.link.set(type_py = enums.GeneratorLink.GPIB, generator = repcap.Generator.Default) \n
		No command help available \n
			:param type_py: No help available
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GeneratorLink)
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:LINK {param}')

	# noinspection PyTypeChecker
	def get(self, generator=repcap.Generator.Default) -> enums.GeneratorLink:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator<gen>:LINK \n
		Snippet: value: enums.GeneratorLink = driver.system.communicate.rdevice.generator.link.get(generator = repcap.Generator.Default) \n
		No command help available \n
			:param generator: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Generator')
			:return: type_py: No help available"""
		generator_cmd_val = self._cmd_group.get_repcap_cmd_value(generator, repcap.Generator)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator{generator_cmd_val}:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorLink)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PtransitionCls:
	"""Ptransition commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ptransition", core, parent)

	def set(self, bit_definition: int, channel_name: str = None) -> None:
		"""SCPI: STATus:QUEStionable:INTegrity:UNCalibrated:PTRansition \n
		Snippet: driver.status.questionable.integrity.uncalibrated.ptransition.set(bit_definition = 1, channel_name = '1') \n
		No command help available \n
			:param bit_definition: No help available
			:param channel_name: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('bit_definition', bit_definition, DataType.Integer), ArgSingle('channel_name', channel_name, DataType.String, None, is_optional=True))
		self._core.io.write(f'STATus:QUEStionable:INTegrity:UNCalibrated:PTRansition {param}'.rstrip())

	# noinspection PyTypeChecker
	class PtransitionStruct(StructBase):
		"""Response structure. Fields: \n
			- Bit_Definition: int: No parameter help available
			- Channel_Name: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_int('Bit_Definition'),
			ArgStruct.scalar_str('Channel_Name')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Bit_Definition: int = None
			self.Channel_Name: str = None

	def get(self) -> PtransitionStruct:
		"""SCPI: STATus:QUEStionable:INTegrity:UNCalibrated:PTRansition \n
		Snippet: value: PtransitionStruct = driver.status.questionable.integrity.uncalibrated.ptransition.get() \n
		No command help available \n
			:return: structure: for return value, see the help for PtransitionStruct structure arguments."""
		return self._core.io.query_struct(f'STATus:QUEStionable:INTegrity:UNCalibrated:PTRansition?', self.__class__.PtransitionStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.FftWindowType) -> None:
		"""SCPI: [SENSe]:IQ:FFT:WINDow:TYPE \n
		Snippet: driver.applications.iqAnalyzer.sense.iq.fft.window.typePy.set(type_py = enums.FftWindowType.BLACkharris) \n
		In the I/Q Analyzer you can select one of several FFT window types. \n
			:param type_py: BLACkharris Blackman-Harris FLATtop Flattop GAUSsian Gauss RECTangular Rectangular P5 5-Term
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.FftWindowType)
		self._core.io.write(f'SENSe:IQ:FFT:WINDow:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FftWindowType:
		"""SCPI: [SENSe]:IQ:FFT:WINDow:TYPE \n
		Snippet: value: enums.FftWindowType = driver.applications.iqAnalyzer.sense.iq.fft.window.typePy.get() \n
		In the I/Q Analyzer you can select one of several FFT window types. \n
			:return: type_py: No help available"""
		response = self._core.io.query_str(f'SENSe:IQ:FFT:WINDow:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.FftWindowType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MbwidthCls:
	"""Mbwidth commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mbwidth", core, parent)

	def set(self, max_bandwidth: int) -> None:
		"""SCPI: TRACe:IQ:WBANd:MBWidth \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.wband.mbwidth.set(max_bandwidth = 1) \n
		Defines the maximum analysis bandwidth. Any value can be specified; the next higher fixed bandwidth is used. \n
			:param max_bandwidth: 80 MHz Restricts the analysis bandwidth to a maximum of 80 MHz. The bandwidth extension option R&S FSWP-B320 is deactivated. method RsFswp.Applications.IqAnalyzer.Trace.Iq.Wband.State.set is set to OFF. 160 MHz Restricts the analysis bandwidth to a maximum of 160 MHz. The bandwidth extension option R&S FSWP-B320 is deactivated. method RsFswp.Applications.IqAnalyzer.Trace.Iq.Wband.State.set is set to ON. 160 MHz | MAX The bandwidth extension option is activated. The currently available maximum bandwidth is allowed. method RsFswp.Applications.IqAnalyzer.Trace.Iq.Wband.State.set is set to ON. Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(max_bandwidth)
		self._core.io.write(f'TRACe:IQ:WBANd:MBWidth {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:WBANd:MBWidth \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.wband.mbwidth.get() \n
		Defines the maximum analysis bandwidth. Any value can be specified; the next higher fixed bandwidth is used. \n
			:return: max_bandwidth: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:WBANd:MBWidth?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class InterfaceCls:
	"""Interface commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interface", core, parent)

	def set(self, type_py: enums.GeneratorIntf) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:INTerface \n
		Snippet: driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.interface.set(type_py = enums.GeneratorIntf.GPIB) \n
		Defines the interface used for the connection to the external generator. \n
			:param type_py: GPIB TCPip
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GeneratorIntf)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:GENerator:INTerface {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.GeneratorIntf:
		"""SCPI: SYSTem:COMMunicate:RDEVice:GENerator:INTerface \n
		Snippet: value: enums.GeneratorIntf = driver.applications.k30NoiseFigure.system.communicate.rdevice.generator.interface.get() \n
		Defines the interface used for the connection to the external generator. \n
			:return: type_py: GPIB TCPip"""
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:GENerator:INTerface?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorIntf)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, data_format: enums.DataFormat) -> None:
		"""SCPI: FORMat[:DATA] \n
		Snippet: driver.formatPy.data.set(data_format = enums.DataFormat.ASCii) \n
		This command selects the data format that is used for transmission of trace data from the R&S FSWP to the controlling
		computer. Note that the command has no effect for data that you send to the R&S FSWP. The R&S FSWP automatically
		recognizes the data it receives, regardless of the format. For details on data formats, see 'Formats for returned values:
		ASCII format and binary format'. \n
			:param data_format: No help available
		"""
		param = Conversions.enum_scalar_to_str(data_format, enums.DataFormat)
		self._core.io.write_with_opc(f'FORMat:DATA {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DataFormat:
		"""SCPI: FORMat[:DATA] \n
		Snippet: value: enums.DataFormat = driver.formatPy.data.get() \n
		This command selects the data format that is used for transmission of trace data from the R&S FSWP to the controlling
		computer. Note that the command has no effect for data that you send to the R&S FSWP. The R&S FSWP automatically
		recognizes the data it receives, regardless of the format. For details on data formats, see 'Formats for returned values:
		ASCII format and binary format'. \n
			:return: data_format: No help available"""
		response = self._core.io.query_str_with_opc(f'FORMat:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.DataFormat)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SwapIqCls:
	"""SwapIq commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("swapIq", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:SWAPiq \n
		Snippet: driver.applications.iqAnalyzer.sense.swapIq.set(state = False) \n
		This command defines whether or not the recorded I/Q pairs should be swapped (I<->Q) before being processed. Swapping I
		and Q inverts the sideband. This is useful if the DUT interchanged the I and Q parts of the signal; then the R&S FSWP can
		do the same to compensate for it. For GSM measurements: Try this function if the TSC can not be found. \n
			:param state: ON | 1 I and Q signals are interchanged Inverted sideband, Q+j*I OFF | 0 I and Q signals are not interchanged Normal sideband, I+j*Q
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:SWAPiq {param}')

	def get(self) -> bool:
		"""SCPI: [SENSe]:SWAPiq \n
		Snippet: value: bool = driver.applications.iqAnalyzer.sense.swapIq.get() \n
		This command defines whether or not the recorded I/Q pairs should be swapped (I<->Q) before being processed. Swapping I
		and Q inverts the sideband. This is useful if the DUT interchanged the I and Q parts of the signal; then the R&S FSWP can
		do the same to compensate for it. For GSM measurements: Try this function if the TSC can not be found. \n
			:return: state: ON | 1 I and Q signals are interchanged Inverted sideband, Q+j*I OFF | 0 I and Q signals are not interchanged Normal sideband, I+j*Q"""
		response = self._core.io.query_str(f'SENSe:SWAPiq?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfunctionCls:
	"""Sfunction commands group definition. 4 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfunction", core, parent)

	@property
	def lastResult(self):
		"""lastResult commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_lastResult'):
			from .LastResult import LastResultCls
			self._lastResult = LastResultCls(self._core, self._cmd_group)
		return self._lastResult

	@property
	def results(self):
		"""results commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_results'):
			from .Results import ResultsCls
			self._results = ResultsCls(self._core, self._cmd_group)
		return self._results

	def set(self, service_function: str) -> None:
		"""SCPI: DIAGnostic:SERVice:SFUNction \n
		Snippet: driver.diagnostic.service.sfunction.set(service_function = '1') \n
		This command starts a service function. The service functions are available after you have entered the level 1 or level 2
		system password. \n
			:param service_function: String containing the ID of the service function. The ID of the service function is made up out of five numbers, separated by a point. • function group number • board number • function number • parameter 1 (see the Service Manual) • parameter 2 (see the Service Manual)
		"""
		param = Conversions.value_to_quoted_str(service_function)
		self._core.io.write(f'DIAGnostic:SERVice:SFUNction {param}')

	def get(self, service_function: str) -> str:
		"""SCPI: DIAGnostic:SERVice:SFUNction \n
		Snippet: value: str = driver.diagnostic.service.sfunction.get(service_function = '1') \n
		This command starts a service function. The service functions are available after you have entered the level 1 or level 2
		system password. \n
			:param service_function: String containing the ID of the service function. The ID of the service function is made up out of five numbers, separated by a point. • function group number • board number • function number • parameter 1 (see the Service Manual) • parameter 2 (see the Service Manual)
			:return: result: String containing the ID of the service function. The ID of the service function is made up out of five numbers, separated by a point. • function group number • board number • function number • parameter 1 (see the Service Manual) • parameter 2 (see the Service Manual)"""
		param = Conversions.value_to_quoted_str(service_function)
		response = self._core.io.query_str(f'DIAGnostic:SERVice:SFUNction? {param}')
		return trim_str_response(response)

	def clone(self) -> 'SfunctionCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SfunctionCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModulationCls:
	"""Modulation commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("modulation", core, parent)

	def set(self, modulation: enums.FrameModulation) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:PREVious:MODulation \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.previous.modulation.set(modulation = enums.FrameModulation.AUTO) \n
		Determines which modulation type is used to demodulate the frame previous to the first configured subframe. This command
		is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:param modulation: AUTO | DATA | PATTern Data The modulation type defined for data symbols is used (see [SENSe:]DDEMod:MAPPing[:VALue]) Pattern The modulation type defined for pattern symbols is used (see [SENSe:]DDEMod:PATTern:MAPPing[:VALue]) . Auto The previous frame uses the same modulation as the last subframe of the frame configuration.
		"""
		param = Conversions.enum_scalar_to_str(modulation, enums.FrameModulation)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:PREVious:MODulation {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FrameModulation:
		"""SCPI: [SENSe]:DDEMod:PATTern:FRAMe:EDIT:PREVious:MODulation \n
		Snippet: value: enums.FrameModulation = driver.applications.k70Vsa.sense.ddemod.pattern.frame.edit.previous.modulation.get() \n
		Determines which modulation type is used to demodulate the frame previous to the first configured subframe. This command
		is only available if the additional Multi-Modulation Analysis option (R&S FSWP-K70M) is installed. \n
			:return: modulation: AUTO | DATA | PATTern Data The modulation type defined for data symbols is used (see [SENSe:]DDEMod:MAPPing[:VALue]) Pattern The modulation type defined for pattern symbols is used (see [SENSe:]DDEMod:PATTern:MAPPing[:VALue]) . Auto The previous frame uses the same modulation as the last subframe of the frame configuration."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FRAMe:EDIT:PREVious:MODulation?')
		return Conversions.str_to_scalar_enum(response, enums.FrameModulation)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StopCls:
	"""Stop commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stop", core, parent)

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> int:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:X[:SCALe]:STOP \n
		Snippet: value: int = driver.applications.k70Vsa.display.window.trace.x.scale.stop.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command queries the last value of the x-axis in the specified window in symbols or time, depending on the unit
		setting for the x-axis. Note: If the burst is shifted (using the CALC:TRAC:ALIG commands) the x-axis no longer begins at
		0 symbols on the left, but at a user-defined value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: stop: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:X:SCALe:STOP?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NextCls:
	"""Next commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("next", core, parent)

	def set(self) -> None:
		"""SCPI: STATus:QUEue[:NEXT] \n
		Snippet: driver.status.queue.next.set() \n
		This command queries the most recent error queue entry and deletes it. Positive error numbers indicate device-specific
		errors, negative error numbers are error messages defined by SCPI. If the error queue is empty, the error number 0, 'No
		error', is returned. This command is identical to the SYSTem:ERRor[:NEXT]? command. \n
		"""
		self._core.io.write(f'STATus:QUEue:NEXT')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: STATus:QUEue[:NEXT] \n
		Snippet: driver.status.queue.next.set_with_opc() \n
		This command queries the most recent error queue entry and deletes it. Positive error numbers indicate device-specific
		errors, negative error numbers are error messages defined by SCPI. If the error queue is empty, the error number 0, 'No
		error', is returned. This command is identical to the SYSTem:ERRor[:NEXT]? command. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'STATus:QUEue:NEXT', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CommonCls:
	"""Common commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("common", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNCertainty:COMMon \n
		Snippet: driver.applications.k30NoiseFigure.calculate.uncertainty.common.set(state = False, window = repcap.Window.Default) \n
		This command turns matching of the noise source characteristics used during calibration and measurement on and off. This
		command is available when you use different noise sources for calibration and measurement ([SENSe:]CORRection:ENR:COMMon
		OFF) . \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNCertainty:COMMon {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:UNCertainty:COMMon \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.calculate.uncertainty.common.get(window = repcap.Window.Default) \n
		This command turns matching of the noise source characteristics used during calibration and measurement on and off. This
		command is available when you use different noise sources for calibration and measurement ([SENSe:]CORRection:ENR:COMMon
		OFF) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNCertainty:COMMon?')
		return Conversions.str_to_bool(response)



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, frequency_enr: List[float], enr: List[float]) -> None:
		"""SCPI: [SENSe]:CORRection:ENR[:MEASurement]:TABLe[:DATA] \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.enr.measurement.table.data.set(frequency_enr = [1.1, 2.2, 3.3], enr = [1.1, 2.2, 3.3]) \n
		This command defines the contents of the currently selected ENR table. Define an ENR for all measurement points.
		Each entry of the ENR table consists of one measurement point and the corresponding ENR. The individual values are
		separated by commas or spaces. The table can contain up to 10001 entries. If you create a new table with this command, it
		overwrites the current entries of the frequency list.
		To select the ENR table to edit, use [SENSe:]CORRection:ENR[:MEASurement]:TABLe[:DATA]. \n
			:param frequency_enr: Frequency of the measurement point. Range: 0 Hz to 999.99 GHz, Unit: HZ
			:param enr: Unit: DB
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle.as_open_list('frequency_enr', frequency_enr, DataType.FloatList, None), ArgSingle.as_open_list('enr', enr, DataType.FloatList, None))
		self._core.io.write(f'SENSe:CORRection:ENR:MEASurement:TABLe:DATA {param}'.rstrip())

	# noinspection PyTypeChecker
	class DataStruct(StructBase):
		"""Response structure. Fields: \n
			- Frequency_Enr: List[float]: Frequency of the measurement point. Range: 0 Hz to 999.99 GHz, Unit: HZ
			- Enr: List[float]: Unit: DB"""
		__meta_args_list = [
			ArgStruct('Frequency_Enr', DataType.FloatList, None, False, True, 1),
			ArgStruct('Enr', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Frequency_Enr: List[float] = None
			self.Enr: List[float] = None

	def get(self) -> DataStruct:
		"""SCPI: [SENSe]:CORRection:ENR[:MEASurement]:TABLe[:DATA] \n
		Snippet: value: DataStruct = driver.applications.k30NoiseFigure.sense.correction.enr.measurement.table.data.get() \n
		This command defines the contents of the currently selected ENR table. Define an ENR for all measurement points.
		Each entry of the ENR table consists of one measurement point and the corresponding ENR. The individual values are
		separated by commas or spaces. The table can contain up to 10001 entries. If you create a new table with this command, it
		overwrites the current entries of the frequency list.
		To select the ENR table to edit, use [SENSe:]CORRection:ENR[:MEASurement]:TABLe[:DATA]. \n
			:return: structure: for return value, see the help for DataStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:CORRection:ENR:MEASurement:TABLe:DATA?', self.__class__.DataStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, file_format: enums.FileFormat) -> None:
		"""SCPI: FORMat:DEXPort:FORMat \n
		Snippet: driver.applications.k30NoiseFigure.formatPy.dexport.formatPy.set(file_format = enums.FileFormat.CSV) \n
		No command help available \n
			:param file_format: No help available
		"""
		param = Conversions.enum_scalar_to_str(file_format, enums.FileFormat)
		self._core.io.write(f'FORMat:DEXPort:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.FileFormat:
		"""SCPI: FORMat:DEXPort:FORMat \n
		Snippet: value: enums.FileFormat = driver.applications.k30NoiseFigure.formatPy.dexport.formatPy.get() \n
		No command help available \n
			:return: file_format: No help available"""
		response = self._core.io.query_str(f'FORMat:DEXPort:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.FileFormat)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PageSizeCls:
	"""PageSize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pageSize", core, parent)

	def set(self, size: enums.HardcopyPageSize) -> None:
		"""SCPI: HCOPy:TREPort:PAGesize \n
		Snippet: driver.hardCopy.treport.pageSize.set(size = enums.HardcopyPageSize.A4) \n
		No command help available \n
			:param size: No help available
		"""
		param = Conversions.enum_scalar_to_str(size, enums.HardcopyPageSize)
		self._core.io.write(f'HCOPy:TREPort:PAGesize {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.HardcopyPageSize:
		"""SCPI: HCOPy:TREPort:PAGesize \n
		Snippet: value: enums.HardcopyPageSize = driver.hardCopy.treport.pageSize.get() \n
		No command help available \n
			:return: size: No help available"""
		response = self._core.io.query_str(f'HCOPy:TREPort:PAGesize?')
		return Conversions.str_to_scalar_enum(response, enums.HardcopyPageSize)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Types import DataType
from ....Internal.Utilities import trim_str_response
from ....Internal.ArgSingleList import ArgSingleList
from ....Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PathCls:
	"""Path commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def set(self, file_path: str, analysis_bw: float) -> None:
		"""SCPI: INPut:FILE:PATH \n
		Snippet: driver.inputPy.file.path.set(file_path = '1', analysis_bw = 1.0) \n
		This command selects the I/Q data file to be used as input for further measurements. The I/Q data must have a specific
		format as described in 'I/Q data file format (iq-tar) '. For details, see 'Basics on input from I/Q data files'. \n
			:param file_path: No help available
			:param analysis_bw: Optionally: The analysis bandwidth to be used by the measurement. The bandwidth must be smaller than or equal to the bandwidth of the data that was stored in the file. Unit: HZ
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('file_path', file_path, DataType.String), ArgSingle('analysis_bw', analysis_bw, DataType.Float))
		self._core.io.write_with_opc(f'INPut:FILE:PATH {param}'.rstrip())

	def get(self) -> str:
		"""SCPI: INPut:FILE:PATH \n
		Snippet: value: str = driver.inputPy.file.path.get() \n
		This command selects the I/Q data file to be used as input for further measurements. The I/Q data must have a specific
		format as described in 'I/Q data file format (iq-tar) '. For details, see 'Basics on input from I/Q data files'. \n
			:return: file_path: No help available"""
		response = self._core.io.query_str_with_opc(f'INPut:FILE:PATH?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, harm_order: float) -> None:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH[:VALue] \n
		Snippet: driver.applications.k60Transient.sense.mixer.harmonic.high.value.set(harm_order = 1.0) \n
		No command help available \n
			:param harm_order: No help available
		"""
		param = Conversions.decimal_value_to_str(harm_order)
		self._core.io.write(f'SENSe:MIXer:HARMonic:HIGH:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH[:VALue] \n
		Snippet: value: float = driver.applications.k60Transient.sense.mixer.harmonic.high.value.get() \n
		No command help available \n
			:return: harm_order: No help available"""
		response = self._core.io.query_str(f'SENSe:MIXer:HARMonic:HIGH:VALue?')
		return Conversions.str_to_float(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FrequencyCls:
	"""Frequency commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("frequency", core, parent)

	def set(self) -> None:
		"""SCPI: [SENSe]:ADJust:FREQuency \n
		Snippet: driver.sense.adjust.frequency.set() \n
		This command sets the center frequency to the frequency with the highest signal level in the current frequency range. \n
		"""
		self._core.io.write(f'SENSe:ADJust:FREQuency')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SENSe]:ADJust:FREQuency \n
		Snippet: driver.sense.adjust.frequency.set_with_opc() \n
		This command sets the center frequency to the frequency with the highest signal level in the current frequency range. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:ADJust:FREQuency', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 6 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	@property
	def absolute(self):
		"""absolute commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_absolute'):
			from .Absolute import AbsoluteCls
			self._absolute = AbsoluteCls(self._core, self._cmd_group)
		return self._absolute

	@property
	def caclr(self):
		"""caclr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_caclr'):
			from .Caclr import CaclrCls
			self._caclr = CaclrCls(self._core, self._cmd_group)
		return self._caclr

	@property
	def aclr(self):
		"""aclr commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_aclr'):
			from .Aclr import AclrCls
			self._aclr = AclrCls(self._core, self._cmd_group)
		return self._aclr

	def clone(self) -> 'AutoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = AutoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, count: int) -> None:
		"""SCPI: TRACe:IQ:AVERage:COUNt \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.average.count.set(count = 1) \n
		This command defines the number of I/Q data sets that the averaging is based on. \n
			:param count: Range: 0 to 32767
		"""
		param = Conversions.decimal_value_to_str(count)
		self._core.io.write(f'TRACe:IQ:AVERage:COUNt {param}')

	def get(self) -> int:
		"""SCPI: TRACe:IQ:AVERage:COUNt \n
		Snippet: value: int = driver.applications.iqAnalyzer.trace.iq.average.count.get() \n
		This command defines the number of I/Q data sets that the averaging is based on. \n
			:return: count: No help available"""
		response = self._core.io.query_str(f'TRACe:IQ:AVERage:COUNt?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, window=repcap.Window.Default) -> str:
		"""SCPI: CALCulate<n>:LIMit:MACCuracy:CFERror:PEAK[:RESult] \n
		Snippet: value: str = driver.applications.k70Vsa.calculate.limit.maccuracy.cfError.peak.result.get(window = repcap.Window.Default) \n
		This command queries whether the limit for the specified result type and limit type was violated. For details on result
		types and limit types see 'Result summary'. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: result: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit:MACCuracy:CFERror:PEAK:RESult?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FromPyCls:
	"""FromPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fromPy", core, parent)

	def set(self, port_from: int, inputIx=repcap.InputIx.Default, touchStone=repcap.TouchStone.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:SLISt<sli>:PORTs:FROM \n
		Snippet: driver.sense.correction.fresponse.inputPy.user.slist.ports.fromPy.set(port_from = 1, inputIx = repcap.InputIx.Default, touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param port_from: No help available
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
		"""
		param = Conversions.decimal_value_to_str(port_from)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		self._core.io.write(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:SLISt{touchStone_cmd_val}:PORTs:FROM {param}')

	def get(self, inputIx=repcap.InputIx.Default, touchStone=repcap.TouchStone.Default) -> int:
		"""SCPI: [SENSe]:CORRection:FRESponse:INPut<ip>:USER:SLISt<sli>:PORTs:FROM \n
		Snippet: value: int = driver.sense.correction.fresponse.inputPy.user.slist.ports.fromPy.get(inputIx = repcap.InputIx.Default, touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:return: port_from: No help available"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		response = self._core.io.query_str(f'SENSe:CORRection:FRESponse:INPut{inputIx_cmd_val}:USER:SLISt{touchStone_cmd_val}:PORTs:FROM?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OptimizeCls:
	"""Optimize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("optimize", core, parent)

	def set(self, mode: enums.SweepOptimize) -> None:
		"""SCPI: [SENSe]:SWEep:OPTimize \n
		Snippet: driver.sense.sweep.optimize.set(mode = enums.SweepOptimize.AUTO) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.SweepOptimize)
		self._core.io.write(f'SENSe:SWEep:OPTimize {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.SweepOptimize:
		"""SCPI: [SENSe]:SWEep:OPTimize \n
		Snippet: value: enums.SweepOptimize = driver.sense.sweep.optimize.get() \n
		No command help available \n
			:return: mode: No help available"""
		response = self._core.io.query_str(f'SENSe:SWEep:OPTimize?')
		return Conversions.str_to_scalar_enum(response, enums.SweepOptimize)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SrNumberCls:
	"""SrNumber commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("srNumber", core, parent)

	def set(self, serial_number: str) -> None:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:SNS:SRNumber \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.enr.calibration.sns.srNumber.set(serial_number = '1') \n
		This command sets and queries the calibration noise source smart noise source serial number. \n
			:param serial_number: No help available
		"""
		param = Conversions.value_to_quoted_str(serial_number)
		self._core.io.write(f'SENSe:CORRection:ENR:CALibration:SNS:SRNumber {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:SNS:SRNumber \n
		Snippet: value: str = driver.applications.k30NoiseFigure.sense.correction.enr.calibration.sns.srNumber.get() \n
		This command sets and queries the calibration noise source smart noise source serial number. \n
			:return: serial_number: No help available"""
		response = self._core.io.query_str(f'SENSe:CORRection:ENR:CALibration:SNS:SRNumber?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Types import DataType
from ...Internal.ArgSingleList import ArgSingleList
from ...Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MassMemoryCls:
	"""MassMemory commands group definition. 69 total commands, 14 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("massMemory", core, parent)

	@property
	def clear(self):
		"""clear commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_clear'):
			from .Clear import ClearCls
			self._clear = ClearCls(self._core, self._cmd_group)
		return self._clear

	@property
	def load(self):
		"""load commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_load'):
			from .Load import LoadCls
			self._load = LoadCls(self._core, self._cmd_group)
		return self._load

	@property
	def store(self):
		"""store commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_store'):
			from .Store import StoreCls
			self._store = StoreCls(self._core, self._cmd_group)
		return self._store

	@property
	def currentDirectory(self):
		"""currentDirectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_currentDirectory'):
			from .CurrentDirectory import CurrentDirectoryCls
			self._currentDirectory = CurrentDirectoryCls(self._core, self._cmd_group)
		return self._currentDirectory

	@property
	def network(self):
		"""network commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_network'):
			from .Network import NetworkCls
			self._network = NetworkCls(self._core, self._cmd_group)
		return self._network

	@property
	def select(self):
		"""select commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_select'):
			from .Select import SelectCls
			self._select = SelectCls(self._core, self._cmd_group)
		return self._select

	@property
	def name(self):
		"""name commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_name'):
			from .Name import NameCls
			self._name = NameCls(self._core, self._cmd_group)
		return self._name

	@property
	def raw(self):
		"""raw commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_raw'):
			from .Raw import RawCls
			self._raw = RawCls(self._core, self._cmd_group)
		return self._raw

	@property
	def catalog(self):
		"""catalog commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_catalog'):
			from .Catalog import CatalogCls
			self._catalog = CatalogCls(self._core, self._cmd_group)
		return self._catalog

	@property
	def delete(self):
		"""delete commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_delete'):
			from .Delete import DeleteCls
			self._delete = DeleteCls(self._core, self._cmd_group)
		return self._delete

	@property
	def makeDirectory(self):
		"""makeDirectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_makeDirectory'):
			from .MakeDirectory import MakeDirectoryCls
			self._makeDirectory = MakeDirectoryCls(self._core, self._cmd_group)
		return self._makeDirectory

	@property
	def msis(self):
		"""msis commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_msis'):
			from .Msis import MsisCls
			self._msis = MsisCls(self._core, self._cmd_group)
		return self._msis

	@property
	def deleteDirectory(self):
		"""deleteDirectory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_deleteDirectory'):
			from .DeleteDirectory import DeleteDirectoryCls
			self._deleteDirectory = DeleteDirectoryCls(self._core, self._cmd_group)
		return self._deleteDirectory

	@property
	def comment(self):
		"""comment commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_comment'):
			from .Comment import CommentCls
			self._comment = CommentCls(self._core, self._cmd_group)
		return self._comment

	def clear_all(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: MMEMory:CLEar:ALL \n
		Snippet: driver.massMemory.clear_all() \n
		This command deletes all instrument configuration files in the current directory. You can select the directory with
		method RsFswp.MassMemory.CurrentDirectory.set. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'MMEMory:CLEar:ALL', opc_timeout_ms)

	def copy(self, source_file: str, target_file: str) -> None:
		"""SCPI: MMEMory:COPY \n
		Snippet: driver.massMemory.copy(source_file = '1', target_file = '1') \n
		This command copies one or more files to another directory. \n
			:param source_file: No help available
			:param target_file: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('source_file', source_file, DataType.String), ArgSingle('target_file', target_file, DataType.String))
		self._core.io.write_with_opc(f'MMEMory:COPY {param}'.rstrip())

	def move(self, source_file: str, target_file: str) -> None:
		"""SCPI: MMEMory:MOVE \n
		Snippet: driver.massMemory.move(source_file = '1', target_file = '1') \n
		This command moves a file to another directory. The command also renames the file if you define a new name in the target
		directory. If you do not include a path for <NewFileName>, the command just renames the file. \n
			:param source_file: No help available
			:param target_file: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('source_file', source_file, DataType.String), ArgSingle('target_file', target_file, DataType.String))
		self._core.io.write_with_opc(f'MMEMory:MOVE {param}'.rstrip())

	def clone(self) -> 'MassMemoryCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = MassMemoryCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImmediateCls:
	"""Immediate commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("immediate", core, parent)

	@property
	def next(self):
		"""next commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_next'):
			from .Next import NextCls
			self._next = NextCls(self._core, self._cmd_group)
		return self._next

	def set(self) -> None:
		"""SCPI: HCOPy[:IMMediate] \n
		Snippet: driver.hardCopy.immediate.set() \n
		This command initiates a print job. If you are printing to a file, the file name depends on method RsFswp.MassMemory.Name.
		set. \n
		"""
		self._core.io.write(f'HCOPy:IMMediate')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: HCOPy[:IMMediate] \n
		Snippet: driver.hardCopy.immediate.set_with_opc() \n
		This command initiates a print job. If you are printing to a file, the file name depends on method RsFswp.MassMemory.Name.
		set. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'HCOPy:IMMediate', opc_timeout_ms)

	def clone(self) -> 'ImmediateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ImmediateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, level: float) -> None:
		"""SCPI: INSTrument:COUPle:GENerator:RLEVel:OFFSet \n
		Snippet: driver.instrument.couple.generator.refLevel.offset.set(level = 1.0) \n
		No command help available \n
			:param level: No help available
		"""
		param = Conversions.decimal_value_to_str(level)
		self._core.io.write(f'INSTrument:COUPle:GENerator:RLEVel:OFFSet {param}')

	def get(self) -> float:
		"""SCPI: INSTrument:COUPle:GENerator:RLEVel:OFFSet \n
		Snippet: value: float = driver.instrument.couple.generator.refLevel.offset.get() \n
		No command help available \n
			:return: level: No help available"""
		response = self._core.io.query_str(f'INSTrument:COUPle:GENerator:RLEVel:OFFSet?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ListPyCls:
	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("listPy", core, parent)

	def get(self) -> str:
		"""SCPI: MMEMory:LOAD:IQ:STReam:LIST \n
		Snippet: value: str = driver.applications.k70Vsa.massMemory.load.iq.stream.listPy.get() \n
		No command help available \n
			:return: channel: No help available"""
		response = self._core.io.query_str(f'MMEMory:LOAD:IQ:STReam:LIST?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.RepeatedCapability import RepeatedCapability
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EspectrumCls:
	"""Espectrum commands group definition. 47 total commands, 11 Subgroups, 0 group commands
	Repeated Capability: SubBlock, default value after init: SubBlock.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("espectrum", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_subBlock_get', 'repcap_subBlock_set', repcap.SubBlock.Nr1)

	def repcap_subBlock_set(self, subBlock: repcap.SubBlock) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to SubBlock.Default
		Default value after init: SubBlock.Nr1"""
		self._cmd_group.set_repcap_enum_value(subBlock)

	def repcap_subBlock_get(self) -> repcap.SubBlock:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def range(self):
		"""range commands group. 11 Sub-classes, 1 commands."""
		if not hasattr(self, '_range'):
			from .Range import RangeCls
			self._range = RangeCls(self._core, self._cmd_group)
		return self._range

	@property
	def scenter(self):
		"""scenter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scenter'):
			from .Scenter import ScenterCls
			self._scenter = ScenterCls(self._core, self._cmd_group)
		return self._scenter

	@property
	def scount(self):
		"""scount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scount'):
			from .Scount import ScountCls
			self._scount = ScountCls(self._core, self._cmd_group)
		return self._scount

	@property
	def bwid(self):
		"""bwid commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bwid'):
			from .Bwid import BwidCls
			self._bwid = BwidCls(self._core, self._cmd_group)
		return self._bwid

	@property
	def filterPy(self):
		"""filterPy commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def rrange(self):
		"""rrange commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rrange'):
			from .Rrange import RrangeCls
			self._rrange = RrangeCls(self._core, self._cmd_group)
		return self._rrange

	@property
	def rtype(self):
		"""rtype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rtype'):
			from .Rtype import RtypeCls
			self._rtype = RtypeCls(self._core, self._cmd_group)
		return self._rtype

	@property
	def preset(self):
		"""preset commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_preset'):
			from .Preset import PresetCls
			self._preset = PresetCls(self._core, self._cmd_group)
		return self._preset

	@property
	def hspeed(self):
		"""hspeed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hspeed'):
			from .Hspeed import HspeedCls
			self._hspeed = HspeedCls(self._core, self._cmd_group)
		return self._hspeed

	@property
	def msr(self):
		"""msr commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_msr'):
			from .Msr import MsrCls
			self._msr = MsrCls(self._core, self._cmd_group)
		return self._msr

	@property
	def ssetup(self):
		"""ssetup commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ssetup'):
			from .Ssetup import SsetupCls
			self._ssetup = SsetupCls(self._core, self._cmd_group)
		return self._ssetup

	def clone(self) -> 'EspectrumCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EspectrumCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RhoCls:
	"""Rho commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rho", core, parent)

	def get(self, result_type: enums.ResultTypeStat, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:DDEMod:STATistic:RHO \n
		Snippet: value: float = driver.applications.k70Vsa.calculate.marker.function.ddemod.statistic.rho.get(result_type = enums.ResultTypeStat.AVG, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the results of the Rho factor measurement performed for digital demodulation. \n
			:param result_type: none Rho factor (for current sweep) AVG Average rho factor over several sweeps RPE Peak rho factor over several sweeps SDEV Standard deviation of rho factor PCTL 95 percentile value of rho factor
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: result: No help available"""
		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeStat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:DDEMod:STATistic:RHO? {param}')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConnectorCls:
	"""Connector commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("connector", core, parent)

	def set(self, input_connectors: enums.InputConnectorC) -> None:
		"""SCPI: INPut:CONNector \n
		Snippet: driver.applications.k50Spurious.inputPy.connector.set(input_connectors = enums.InputConnectorC.RF) \n
		Determines which connector the input for the measurement is taken from. \n
			:param input_connectors: No help available
		"""
		param = Conversions.enum_scalar_to_str(input_connectors, enums.InputConnectorC)
		self._core.io.write(f'INPut:CONNector {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.InputConnectorC:
		"""SCPI: INPut:CONNector \n
		Snippet: value: enums.InputConnectorC = driver.applications.k50Spurious.inputPy.connector.get() \n
		Determines which connector the input for the measurement is taken from. \n
			:return: input_connectors: No help available"""
		response = self._core.io.query_str(f'INPut:CONNector?')
		return Conversions.str_to_scalar_enum(response, enums.InputConnectorC)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, type_py: enums.EgateType) -> None:
		"""SCPI: TRACe:IQ:EGATe:TYPE \n
		Snippet: driver.applications.iqAnalyzer.trace.iq.egate.typePy.set(type_py = enums.EgateType.EDGE) \n
		This command selects the gate mode for gated measurements with the I/Q analyzer. Note: The IF power trigger holdoff time
		is ignored if you are using the 'Level' gate mode in combination with an IF Power trigger. \n
			:param type_py: LEVel EDGE
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.EgateType)
		self._core.io.write(f'TRACe:IQ:EGATe:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.EgateType:
		"""SCPI: TRACe:IQ:EGATe:TYPE \n
		Snippet: value: enums.EgateType = driver.applications.iqAnalyzer.trace.iq.egate.typePy.get() \n
		This command selects the gate mode for gated measurements with the I/Q analyzer. Note: The IF power trigger holdoff time
		is ignored if you are using the 'Level' gate mode in combination with an IF Power trigger. \n
			:return: type_py: LEVel EDGE"""
		response = self._core.io.query_str(f'TRACe:IQ:EGATe:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.EgateType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NfftCls:
	"""Nfft commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("nfft", core, parent)

	def set(self, loffset: float, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:NFFT \n
		Snippet: driver.applications.k50Spurious.sense.listPy.range.nfft.set(loffset = 1.0, rangePy = repcap.RangePy.Default) \n
		Defines the number of FFT averages to be performed for each range or segment. \n
			:param loffset: integer Range: 1 to 20, Unit: DB
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.decimal_value_to_str(loffset)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:NFFT {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> float:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:NFFT \n
		Snippet: value: float = driver.applications.k50Spurious.sense.listPy.range.nfft.get(rangePy = repcap.RangePy.Default) \n
		Defines the number of FFT averages to be performed for each range or segment. \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: loffset: integer Range: 1 to 20, Unit: DB"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:NFFT?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpotCls:
	"""Spot commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spot", core, parent)

	@property
	def hot(self):
		"""hot commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hot'):
			from .Hot import HotCls
			self._hot = HotCls(self._core, self._cmd_group)
		return self._hot

	@property
	def cold(self):
		"""cold commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cold'):
			from .Cold import ColdCls
			self._cold = ColdCls(self._core, self._cmd_group)
		return self._cold

	def set(self, enr: float) -> None:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:SPOT \n
		Snippet: driver.applications.k30NoiseFigure.sense.correction.enr.calibration.spot.set(enr = 1.0) \n
		This command defines the constant ENR for all measurement points during calibration. This command is available when you
		use different noise sources for calibration and measurement ([SENSe:]CORRection:ENR:COMMon OFF) . \n
			:param enr: Range: -999.99 to 999.99, Unit: DB
		"""
		param = Conversions.decimal_value_to_str(enr)
		self._core.io.write(f'SENSe:CORRection:ENR:CALibration:SPOT {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:CORRection:ENR:CALibration:SPOT \n
		Snippet: value: float = driver.applications.k30NoiseFigure.sense.correction.enr.calibration.spot.get() \n
		This command defines the constant ENR for all measurement points during calibration. This command is available when you
		use different noise sources for calibration and measurement ([SENSe:]CORRection:ENR:COMMon OFF) . \n
			:return: enr: Range: -999.99 to 999.99, Unit: DB"""
		response = self._core.io.query_str(f'SENSe:CORRection:ENR:CALibration:SPOT?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'SpotCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SpotCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ColumnCls:
	"""Column commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("column", core, parent)

	def set(self, state: bool, headers: List[enums.HeadersK50]) -> None:
		"""SCPI: CALCulate:SSEarch:TABLe:COLumn \n
		Snippet: driver.applications.k50Spurious.calculate.ssearch.table.column.set(state = False, headers = [HeadersK50.ALL, HeadersK50.STOP]) \n
		Select the numerical results to be displayed in the Spurious Detection Table. For a description of the individual results
		see 'Spurious Detection Table'. \n
			:param state: ON | OFF | 0 | 1 OFF | 0 Hides the result ON | 1 Displays the result
			:param headers: ALL | SID | STARt | STOP | RBW | FREQuency | POWer | DELTa | IDENt ALL All available results are displayed STARt Start frequency of range/span STOP Stop frequency of range/span FREQuency Spur frequency POWer Spur power DELTa Delta of spur to limit RBW Resolution bandwidth used for range IDENt Spur ID
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('state', state, DataType.Boolean), ArgSingle.as_open_list('headers', headers, DataType.EnumList, enums.HeadersK50))
		self._core.io.write(f'CALCulate:SSEarch:TABLe:COLumn {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self) -> List[enums.HeadersK50]:
		"""SCPI: CALCulate:SSEarch:TABLe:COLumn \n
		Snippet: value: List[enums.HeadersK50] = driver.applications.k50Spurious.calculate.ssearch.table.column.get() \n
		Select the numerical results to be displayed in the Spurious Detection Table. For a description of the individual results
		see 'Spurious Detection Table'. \n
			:return: headers: ALL | SID | STARt | STOP | RBW | FREQuency | POWer | DELTa | IDENt ALL All available results are displayed STARt Start frequency of range/span STOP Stop frequency of range/span FREQuency Spur frequency POWer Spur power DELTa Delta of spur to limit RBW Resolution bandwidth used for range IDENt Spur ID"""
		response = self._core.io.query_str(f'CALCulate:SSEarch:TABLe:COLumn?')
		return Conversions.str_to_list_enum(response, enums.HeadersK50)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, event: enums.EventOnce, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:Y[:SCALe]:AUTO \n
		Snippet: driver.display.window.subwindow.trace.y.scale.auto.set(event = enums.EventOnce.ONCE, window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		Automatic scaling of the y-axis is performed once, then switched off again (for all traces) . \n
			:param event: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(event, enums.EventOnce)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe:AUTO {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CouplingCls:
	"""Coupling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("coupling", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SOURce:GENerator:CHANnel:COUPling \n
		Snippet: driver.source.generator.channel.coupling.set(state = False) \n
		This command couples or decouples the signal source configuration across measurement channels. \n
			:param state: ON | 1 Signal source configuration is the same across all measurement channels. OFF | 0 Signal source configuration is different for each measurement channel.
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce:GENerator:CHANnel:COUPling {param}')

	def get(self) -> bool:
		"""SCPI: SOURce:GENerator:CHANnel:COUPling \n
		Snippet: value: bool = driver.source.generator.channel.coupling.get() \n
		This command couples or decouples the signal source configuration across measurement channels. \n
			:return: state: ON | 1 Signal source configuration is the same across all measurement channels. OFF | 0 Signal source configuration is different for each measurement channel."""
		response = self._core.io.query_str(f'SOURce:GENerator:CHANnel:COUPling?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MinimumCls:
	"""Minimum commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("minimum", core, parent)

	def set(self, useful_length: float) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:BURSt:LENGth[:MINimum] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.burst.length.minimum.set(useful_length = 1.0) \n
		This command defines the minimum useful length of a burst. Only those bursts will be recognized that exceed this length.
		The default unit is symbols. The value can also be given in seconds. Note the difference to manual operation:
		<Min_length>Manual= <Min_Useful_Length> + <Run-In> + <Run-Out> \n
			:param useful_length: numeric value Range: 10 to 32000, Unit: Sym
		"""
		param = Conversions.decimal_value_to_str(useful_length)
		self._core.io.write(f'SENSe:DDEMod:SEARch:BURSt:LENGth:MINimum {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:SEARch:BURSt:LENGth[:MINimum] \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.search.burst.length.minimum.get() \n
		This command defines the minimum useful length of a burst. Only those bursts will be recognized that exceed this length.
		The default unit is symbols. The value can also be given in seconds. Note the difference to manual operation:
		<Min_length>Manual= <Min_Useful_Length> + <Run-In> + <Run-Out> \n
			:return: useful_length: numeric value Range: 10 to 32000, Unit: Sym"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:BURSt:LENGth:MINimum?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HwSettingsCls:
	"""HwSettings commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hwSettings", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:HWSettings \n
		Snippet: driver.massMemory.select.channel.item.hwSettings.set(state = False) \n
		This command includes or excludes measurement (hardware) settings when storing or loading a configuration file.
		Measurement settings include:
			- general channel configuration
			- measurement hardware configuration including markers
			- limit lines Note that a configuration may include no more than 8 limit lines. This number includes active limit lines as well as inactive limit lines that were used last. Therefore the combination of inactivate limit lines depends on the sequence of use with method RsFswp.MassMemory.Load.State.set.
			- color settings
			- configuration for the hardcopy output
		Depending on the used command, either the items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those
		from the currently selected channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:param state: ON | OFF | 0 | 1
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'MMEMory:SELect:CHANnel:ITEM:HWSettings {param}')

	def get(self) -> bool:
		"""SCPI: MMEMory:SELect:CHANnel[:ITEM]:HWSettings \n
		Snippet: value: bool = driver.massMemory.select.channel.item.hwSettings.get() \n
		This command includes or excludes measurement (hardware) settings when storing or loading a configuration file.
		Measurement settings include:
			- general channel configuration
			- measurement hardware configuration including markers
			- limit lines Note that a configuration may include no more than 8 limit lines. This number includes active limit lines as well as inactive limit lines that were used last. Therefore the combination of inactivate limit lines depends on the sequence of use with method RsFswp.MassMemory.Load.State.set.
			- color settings
			- configuration for the hardcopy output
		Depending on the used command, either the items from the entire instrument (MMEMory:SELect[:ITEM]...) , or only those
		from the currently selected channel (MMEM:SELect:CHANnel[:ITEM]...) are stored or loaded. \n
			:return: state: ON | OFF | 0 | 1"""
		response = self._core.io.query_str(f'MMEMory:SELect:CHANnel:ITEM:HWSettings?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StoreCls:
	"""Store commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("store", core, parent)

	def set(self, file_path: str) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:BASeband:USER:STORe \n
		Snippet: driver.sense.correction.fresponse.baseband.user.store.set(file_path = '1') \n
		No command help available \n
			:param file_path: No help available
		"""
		param = Conversions.value_to_quoted_str(file_path)
		self._core.io.write(f'SENSe:CORRection:FRESponse:BASeband:USER:STORe {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MakeDirectoryCls:
	"""MakeDirectory commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("makeDirectory", core, parent)

	def set(self, directory: str) -> None:
		"""SCPI: MMEMory:MDIRectory \n
		Snippet: driver.massMemory.makeDirectory.set(directory = '1') \n
		This command creates a new directory. \n
			:param directory: String containing the path and new directory name The path may be relative or absolute.
		"""
		param = Conversions.value_to_quoted_str(directory)
		self._core.io.write(f'MMEMory:MDIRectory {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:MDIRectory \n
		Snippet: value: str = driver.massMemory.makeDirectory.get() \n
		This command creates a new directory. \n
			:return: directory: String containing the path and new directory name The path may be relative or absolute."""
		response = self._core.io.query_str(f'MMEMory:MDIRectory?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SELect \n
		Snippet: driver.display.window.subwindow.trace.select.set(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SELect')

	def set_with_opc(self, window=repcap.Window.Default, subWindow=repcap.SubWindow.Default, trace=repcap.Trace.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		subWindow_cmd_val = self._cmd_group.get_repcap_cmd_value(subWindow, repcap.SubWindow)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		"""SCPI: DISPlay[:WINDow<n>][:SUBWindow<w>]:TRACe<t>:SELect \n
		Snippet: driver.display.window.subwindow.trace.select.set_with_opc(window = repcap.Window.Default, subWindow = repcap.SubWindow.Default, trace = repcap.Trace.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param subWindow: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Subwindow')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DISPlay:WINDow{window_cmd_val}:SUBWindow{subWindow_cmd_val}:TRACe{trace_cmd_val}:SELect', opc_timeout_ms)



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	def get(self, trace_type: enums.TraceNumber, window=repcap.Window.Default) -> List[float]:
		"""SCPI: TRACe<n>[:DATA]:X \n
		Snippet: value: List[float] = driver.trace.data.x.get(trace_type = enums.TraceNumber.BTOBits, window = repcap.Window.Default) \n
		This command queries the horizontal trace data for each sweep point in the specified window, for example the frequency in
		frequency domain or the time in time domain measurements. This is especially useful for traces with non-equidistant
		x-values. \n
			:param trace_type: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
			:return: trace_xdata: No help available"""
		param = Conversions.enum_scalar_to_str(trace_type, enums.TraceNumber)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_bin_or_ascii_float_list(f'FORMAT REAL,32;TRACe{window_cmd_val}:DATA:X? {param}')
		return response



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PasswordCls:
	"""Password commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("password", core, parent)

	def set(self, password: str) -> None:
		"""SCPI: SYSTem:LXI:PASSword \n
		Snippet: driver.system.lxi.password.set(password = '1') \n
		This command defines the 'LAN' password. \n
			:param password: String containing the password.
		"""
		param = Conversions.value_to_quoted_str(password)
		self._core.io.write(f'SYSTem:LXI:PASSword {param}')

	def get(self) -> str:
		"""SCPI: SYSTem:LXI:PASSword \n
		Snippet: value: str = driver.system.lxi.password.get() \n
		This command defines the 'LAN' password. \n
			:return: password: String containing the password."""
		response = self._core.io.query_str(f'SYSTem:LXI:PASSword?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StartCls:
	"""Start commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("start", core, parent)

	def set(self, frequency: float) -> None:
		"""SCPI: [SENSe]:FREQuency:STARt \n
		Snippet: driver.sense.frequency.start.set(frequency = 1.0) \n
		CW, pulsed and VCO measurements: This command defines the start frequency offset of the measurement range. Transient
		measurement: This command defines the start frequency of the transient measurement. Frequency stability measurement: The
		start frequency offset is coupled to the stop time of the frequency stability measurement ([SENSe:]TIME:STOP) . If you
		change the start frequency offset, the stop time is adjusted accordingly. For example, 1 mHz corresponds to 1000 s. \n
			:param frequency: Offset frequencies in half decade steps. Range: See data sheet , Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'SENSe:FREQuency:STARt {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:FREQuency:STARt \n
		Snippet: value: float = driver.sense.frequency.start.get() \n
		CW, pulsed and VCO measurements: This command defines the start frequency offset of the measurement range. Transient
		measurement: This command defines the start frequency of the transient measurement. Frequency stability measurement: The
		start frequency offset is coupled to the stop time of the frequency stability measurement ([SENSe:]TIME:STOP) . If you
		change the start frequency offset, the stop time is adjusted accordingly. For example, 1 mHz corresponds to 1000 s. \n
			:return: frequency: Offset frequencies in half decade steps. Range: See data sheet , Unit: Hz"""
		response = self._core.io.query_str(f'SENSe:FREQuency:STARt?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SortCls:
	"""Sort commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sort", core, parent)

	def set(self, sort_mode: enums.FpeaksSortMode, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:FPEaks:SORT \n
		Snippet: driver.calculate.marker.function.fpeaks.sort.set(sort_mode = enums.FpeaksSortMode.X, window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command selects the order in which the results of a peak search are returned. \n
			:param sort_mode: X Sorts the peaks according to increasing position on the x-axis. Y Sorts the peaks according to decreasing position on the y-axis.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		param = Conversions.enum_scalar_to_str(sort_mode, enums.FpeaksSortMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:FPEaks:SORT {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> enums.FpeaksSortMode:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:FPEaks:SORT \n
		Snippet: value: enums.FpeaksSortMode = driver.calculate.marker.function.fpeaks.sort.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command selects the order in which the results of a peak search are returned. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: sort_mode: X Sorts the peaks according to increasing position on the x-axis. Y Sorts the peaks according to decreasing position on the y-axis."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:FPEaks:SORT?')
		return Conversions.str_to_scalar_enum(response, enums.FpeaksSortMode)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, gain: float) -> None:
		"""SCPI: [SENSe]:DIRected:INPut:GAIN[:VALue] \n
		Snippet: driver.applications.k50Spurious.sense.directed.inputPy.gain.value.set(gain = 1.0) \n
		Defines the gain by the optional preamplifier (if activated for the directed search measurement,
		see [SENSe:]DIRected:INPut:GAIN:STATe) . For R&S FSWP26 or higher models, the input signal is amplified by 30 dB if the
		preamplifier is activated. For R&S FSWP8 or R&S FSWP13 models, different settings are available. \n
			:param gain: 15 dB | 30 dB All other values are rounded to the nearest of these two.
		"""
		param = Conversions.decimal_value_to_str(gain)
		self._core.io.write(f'SENSe:DIRected:INPut:GAIN:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DIRected:INPut:GAIN[:VALue] \n
		Snippet: value: float = driver.applications.k50Spurious.sense.directed.inputPy.gain.value.get() \n
		Defines the gain by the optional preamplifier (if activated for the directed search measurement,
		see [SENSe:]DIRected:INPut:GAIN:STATe) . For R&S FSWP26 or higher models, the input signal is amplified by 30 dB if the
		preamplifier is activated. For R&S FSWP8 or R&S FSWP13 models, different settings are available. \n
			:return: gain: 15 dB | 30 dB All other values are rounded to the nearest of these two."""
		response = self._core.io.query_str(f'SENSe:DIRected:INPut:GAIN:VALue?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TransducerCls:
	"""Transducer commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("transducer", core, parent)

	def set(self, transducer: str, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:TRANsducer \n
		Snippet: driver.sense.listPy.range.transducer.set(transducer = '1', rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param transducer: No help available
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.value_to_quoted_str(transducer)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:TRANsducer {param}')

	def get(self, rangePy=repcap.RangePy.Default) -> str:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:TRANsducer \n
		Snippet: value: str = driver.sense.listPy.range.transducer.get(rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:return: transducer: No help available"""
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		response = self._core.io.query_str(f'SENSe:LIST:RANGe{rangePy_cmd_val}:TRANsducer?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, source=repcap.Source.Default) -> None:
		"""SCPI: SOURce:VOLTage:CONTrol<i>:LEVel[:STATe] \n
		Snippet: driver.applications.k30NoiseFigure.source.voltage.control.level.state.set(state = False, source = repcap.Source.Default) \n
		No command help available \n
			:param state: No help available
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Control')
		"""
		param = Conversions.bool_to_str(state)
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		self._core.io.write(f'SOURce:VOLTage:CONTrol{source_cmd_val}:LEVel:STATe {param}')

	def get(self, source=repcap.Source.Default) -> bool:
		"""SCPI: SOURce:VOLTage:CONTrol<i>:LEVel[:STATe] \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.source.voltage.control.level.state.get(source = repcap.Source.Default) \n
		No command help available \n
			:param source: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Control')
			:return: state: No help available"""
		source_cmd_val = self._cmd_group.get_repcap_cmd_value(source, repcap.Source)
		response = self._core.io.query_str(f'SOURce:VOLTage:CONTrol{source_cmd_val}:LEVel:STATe?')
		return Conversions.str_to_bool(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:MAPPing:CATalog \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.mapping.catalog.get() \n
		This command queries the names of all mappings that are available for the current modulation type and order. A mapping
		describes the assignment of constellation points to symbols. \n
			:return: mappings: list A comma-separated list of strings, with one string for each mapping name."""
		response = self._core.io.query_str(f'SENSe:DDEMod:MAPPing:CATalog?')
		return trim_str_response(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 131 total commands, 13 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def adjust(self):
		"""adjust commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def correction(self):
		"""correction commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_correction'):
			from .Correction import CorrectionCls
			self._correction = CorrectionCls(self._core, self._cmd_group)
		return self._correction

	@property
	def frequency(self):
		"""frequency commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def mixer(self):
		"""mixer commands group. 10 Sub-classes, 0 commands."""
		if not hasattr(self, '_mixer'):
			from .Mixer import MixerCls
			self._mixer = MixerCls(self._core, self._cmd_group)
		return self._mixer

	@property
	def probe(self):
		"""probe commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_probe'):
			from .Probe import ProbeCls
			self._probe = ProbeCls(self._core, self._cmd_group)
		return self._probe

	@property
	def directed(self):
		"""directed commands group. 7 Sub-classes, 2 commands."""
		if not hasattr(self, '_directed'):
			from .Directed import DirectedCls
			self._directed = DirectedCls(self._core, self._cmd_group)
		return self._directed

	@property
	def fplan(self):
		"""fplan commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_fplan'):
			from .Fplan import FplanCls
			self._fplan = FplanCls(self._core, self._cmd_group)
		return self._fplan

	@property
	def listPy(self):
		"""listPy commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_listPy'):
			from .ListPy import ListPyCls
			self._listPy = ListPyCls(self._core, self._cmd_group)
		return self._listPy

	@property
	def pmeter(self):
		"""pmeter commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_pmeter'):
			from .Pmeter import PmeterCls
			self._pmeter = PmeterCls(self._core, self._cmd_group)
		return self._pmeter

	@property
	def measure(self):
		"""measure commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_measure'):
			from .Measure import MeasureCls
			self._measure = MeasureCls(self._core, self._cmd_group)
		return self._measure

	@property
	def creference(self):
		"""creference commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_creference'):
			from .Creference import CreferenceCls
			self._creference = CreferenceCls(self._core, self._cmd_group)
		return self._creference

	@property
	def ssearch(self):
		"""ssearch commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_ssearch'):
			from .Ssearch import SsearchCls
			self._ssearch = SsearchCls(self._core, self._cmd_group)
		return self._ssearch

	@property
	def transfer(self):
		"""transfer commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_transfer'):
			from .Transfer import TransferCls
			self._transfer = TransferCls(self._core, self._cmd_group)
		return self._transfer

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FallingCls:
	"""Falling commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("falling", core, parent)

	def set(self, run_out: float) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:BURSt:SKIP:FALLing \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.burst.skip.falling.set(run_out = 1.0) \n
		This command defines the length of the falling burst edge which is not considered when evaluating the result. \n
			:param run_out: Range: 1 , Unit: SYM
		"""
		param = Conversions.decimal_value_to_str(run_out)
		self._core.io.write(f'SENSe:DDEMod:SEARch:BURSt:SKIP:FALLing {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:SEARch:BURSt:SKIP:FALLing \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.search.burst.skip.falling.get() \n
		This command defines the length of the falling burst edge which is not considered when evaluating the result. \n
			:return: run_out: Range: 1 , Unit: SYM"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:BURSt:SKIP:FALLing?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HistoryCls:
	"""History commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("history", core, parent)

	def get(self) -> bytes:
		"""SCPI: DIAGnostic:HUMS:DEVice:HISTory \n
		Snippet: value: bytes = driver.diagnostic.hums.device.history.get() \n
		No command help available \n
			:return: device_history: No help available"""
		response = self._core.io.query_bin_block_ERROR(f'DIAGnostic:HUMS:DEVice:HISTory?')
		return response

	def delete_all(self) -> None:
		"""SCPI: DIAGnostic:HUMS:DEVice:HISTory:DELete:ALL \n
		Snippet: driver.diagnostic.hums.device.history.delete_all() \n
		No command help available \n
		"""
		self._core.io.write(f'DIAGnostic:HUMS:DEVice:HISTory:DELete:ALL')

	def delete_all_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: DIAGnostic:HUMS:DEVice:HISTory:DELete:ALL \n
		Snippet: driver.diagnostic.hums.device.history.delete_all_with_opc() \n
		No command help available \n
		Same as delete_all, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'DIAGnostic:HUMS:DEVice:HISTory:DELete:ALL', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SelectCls:
	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("select", core, parent)

	def set(self, signal: enums.DiagnosticSignal) -> None:
		"""SCPI: DIAGnostic:SERVice:INPut[:SELect] \n
		Snippet: driver.diagnostic.service.inputPy.select.set(signal = enums.DiagnosticSignal.AIQ) \n
		This command activates or deactivates the use of an internal calibration signal as input for the R&S FSWP. \n
			:param signal: CALibration Uses the calibration signal as RF input. MCALibration Uses the calibration signal for the microwave range as RF input. RF Uses the signal from the RF input. SYNTtwo Uses the calibration signal to check the phase noise of the two synthesizers. A second synthesizer is available as an hardware option.
		"""
		param = Conversions.enum_scalar_to_str(signal, enums.DiagnosticSignal)
		self._core.io.write(f'DIAGnostic:SERVice:INPut:SELect {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class UsePortCls:
	"""UsePort commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("usePort", core, parent)

	def set(self, power_source: enums.PowerSource) -> None:
		"""SCPI: SOURce:VOLTage:USEPort \n
		Snippet: driver.applications.k30NoiseFigure.source.voltage.usePort.set(power_source = enums.PowerSource.VSUPply) \n
		No command help available \n
			:param power_source: No help available
		"""
		param = Conversions.enum_scalar_to_str(power_source, enums.PowerSource)
		self._core.io.write(f'SOURce:VOLTage:USEPort {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.PowerSource:
		"""SCPI: SOURce:VOLTage:USEPort \n
		Snippet: value: enums.PowerSource = driver.applications.k30NoiseFigure.source.voltage.usePort.get() \n
		No command help available \n
			:return: power_source: No help available"""
		response = self._core.io.query_str(f'SOURce:VOLTage:USEPort?')
		return Conversions.str_to_scalar_enum(response, enums.PowerSource)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def set(self, no_power_classes: float, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default, powerClass=repcap.PowerClass.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:PCLass<pc>:COUNt \n
		Snippet: driver.calculate.limit.espectrum.pclass.count.set(no_power_classes = 1.0, window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default, powerClass = repcap.PowerClass.Default) \n
		No command help available \n
			:param no_power_classes: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param powerClass: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pclass')
		"""
		param = Conversions.decimal_value_to_str(no_power_classes)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		powerClass_cmd_val = self._cmd_group.get_repcap_cmd_value(powerClass, repcap.PowerClass)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:PCLass{powerClass_cmd_val}:COUNt {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, subBlock=repcap.SubBlock.Default, powerClass=repcap.PowerClass.Default) -> float:
		"""SCPI: CALCulate<n>:LIMit<li>:ESPectrum<sb>:PCLass<pc>:COUNt \n
		Snippet: value: float = driver.calculate.limit.espectrum.pclass.count.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, subBlock = repcap.SubBlock.Default, powerClass = repcap.PowerClass.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param powerClass: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pclass')
			:return: no_power_classes: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		powerClass_cmd_val = self._cmd_group.get_repcap_cmd_value(powerClass, repcap.PowerClass)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ESPectrum{subBlock_cmd_val}:PCLass{powerClass_cmd_val}:COUNt?')
		return Conversions.str_to_float(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, cal_state: enums.CalibrationScope = None) -> None:
		"""SCPI: CALibration[:ALL] \n
		Snippet: driver.calibration.all.set(cal_state = enums.CalibrationScope.ACLear) \n
		This command initiates a calibration (self-alignment) routine and queries if calibration was successful.
		During the acquisition of correction data the instrument does not accept any remote control commands. Note:If you start a
		self-alignment remotely, then select the 'Local' softkey while the alignment is still running, the instrument only
		returns to the manual operation state after the alignment is completed. In order to recognize when the acquisition of
		correction data is completed, the MAV bit in the status byte can be used. If the associated bit is set in the Service
		Request Enable (SRE) register, the instrument generates a service request after the acquisition of correction data has
		been completed. \n
			:param cal_state: No help available
		"""
		param = ''
		if cal_state:
			param = Conversions.enum_scalar_to_str(cal_state, enums.CalibrationScope)
		self._core.io.write(f'CALibration:ALL {param}'.strip())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResolutionCls:
	"""Resolution commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("resolution", core, parent)

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:IQ:BWIDth:RESolution \n
		Snippet: driver.sense.iq.bandwidth.resolution.set(bandwidth = 1.0) \n
		This command defines the resolution bandwidth manually if [SENSe:]IQ:BWIDth:MODE is set to MAN. Defines the resolution
		bandwidth. The available RBW values depend on the sample rate and record length. For details see 'Frequency resolution of
		FFT results - RBW'. \n
			:param bandwidth: refer to data sheet Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:IQ:BWIDth:RESolution {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:IQ:BWIDth:RESolution \n
		Snippet: value: float = driver.sense.iq.bandwidth.resolution.get() \n
		This command defines the resolution bandwidth manually if [SENSe:]IQ:BWIDth:MODE is set to MAN. Defines the resolution
		bandwidth. The available RBW values depend on the sample rate and record length. For details see 'Frequency resolution of
		FFT results - RBW'. \n
			:return: bandwidth: refer to data sheet Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:IQ:BWIDth:RESolution?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LengthCls:
	"""Length commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("length", core, parent)

	def set(self, percent: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:CHRDetection:PNOise:LENGth \n
		Snippet: driver.applications.k60Transient.calculate.chrDetection.pnoise.length.set(percent = 1.0, window = repcap.Window.Default) \n
		Defines the length of the measurement range for power results in percent of the chirp length. This command is only
		available if the reference is CENT (see method RsFswp.Applications.K60_Transient.Calculate.ChrDetection.Pnoise.Reference.
		set) . \n
			:param percent: percent of the chirp length Range: 0 to 100
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(percent)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:CHRDetection:PNOise:LENGth {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:CHRDetection:PNOise:LENGth \n
		Snippet: value: float = driver.applications.k60Transient.calculate.chrDetection.pnoise.length.get(window = repcap.Window.Default) \n
		Defines the length of the measurement range for power results in percent of the chirp length. This command is only
		available if the reference is CENT (see method RsFswp.Applications.K60_Transient.Calculate.ChrDetection.Pnoise.Reference.
		set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: percent: percent of the chirp length Range: 0 to 100"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:CHRDetection:PNOise:LENGth?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNCertainty:PREamp:STATe \n
		Snippet: driver.applications.k30NoiseFigure.calculate.uncertainty.preamp.state.set(state = False, window = repcap.Window.Default) \n
		This command includes or excludes an external preamplifier from the uncertainty calculation. If the test setup uses an
		external preamplifier, you also have to define its 'noise figure' and 'gain' values. \n
			:param state: ON | OFF | 1 | 0
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.bool_to_str(state)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNCertainty:PREamp:STATe {param}')

	def get(self, window=repcap.Window.Default) -> bool:
		"""SCPI: CALCulate<n>:UNCertainty:PREamp:STATe \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.calculate.uncertainty.preamp.state.get(window = repcap.Window.Default) \n
		This command includes or excludes an external preamplifier from the uncertainty calculation. If the test setup uses an
		external preamplifier, you also have to define its 'noise figure' and 'gain' values. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: state: ON | OFF | 1 | 0"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNCertainty:PREamp:STATe?')
		return Conversions.str_to_bool(response)
